@@ -1,10 +1,10 @@
 use strict;
 use warnings;
+use diagnostics;
 
 package Archive::BagIt::Base;
 
-use Moose;
-use namespace::autoclean;
+use Moo;
 
 use utf8;
 use open ':std', ':encoding(utf8)';
@@ -17,13 +17,20 @@ use Class::Load qw(load_class);
 use Carp;
 use List::Util qw(uniq);
 
-our $VERSION = '0.057'; # VERSION
+our $VERSION = '0.058'; # VERSION
 
 use Sub::Quote;
 
 my $DEBUG=0;
 
 
+has 'parallel' => ( # used for parallel verify, only usefull if bagits with many files expected!
+    is        => 'rw',
+    predicate => 'has_parallel',
+    default   => undef,
+);
+
+
 has 'bag_path' => (
     is => 'rw',
 );
@@ -196,17 +203,17 @@ has 'non_payload_files' => (
 
 has 'plugins' => (
     is=>'rw',
-    isa=>'HashRef',
+    #isa=>'HashRef',
 );
 
 has 'manifests' => (
     is=>'rw',
-    isa=>'HashRef',
+    #isa=>'HashRef',
 );
 
 has 'algos' => (
     is=>'rw',
-    isa=>'HashRef',
+    #isa=>'HashRef',
 );
 
 
@@ -305,8 +312,8 @@ sub __build_xxxmanifest_entries {
     $algo =~ s#//#/#g; # to fix problems with double path-separators
     $algo =~ s#^($bag_path/).bagit/#$1#; # FIXME: only for dotbagit-variant, if dotbagit will be outdated, this should be removed
     $algo =~ s#^$bag_path/##;
-    $algo =~ s#^tag##;
-    $algo =~ s#^manifest-([a-z0-9]+)\.txt$#$1#;
+    $algo =~ s#tag(manifest-[a-z0-9]+\.txt)#$1#;
+    $algo =~ s#.*manifest-([a-z0-9]+)\.txt$#$1#;
     if ($algo =~ m#/#) {
         die "wrong replacement of path $xxmanifest_file to determine algorithm '$algo' correctly, please contact author";
     }
@@ -510,58 +517,107 @@ sub _verify_XXX_manifests {
     my ($self, $xxprefix, $xxmanifest_entries, $files, $return_all_errors) =@_;
     # Read the manifest file
     my @payload = @{ $files };
-    my %invalids;
+    my @invalid_messages;
     my $bagit = $self->bag_path;
     my $version = $self->bag_version();
-    my %seen; # mark all processed files
+    my sub _invalid_report_or_die {
+        my $message = shift;
+        if ($return_all_errors) {
+            push @invalid_messages, $message;
+        } else {
+            die($message);
+        }
+        return;
+    }
+    foreach my $local_name (@payload) {
+        # local_name is relative to bagit base
+        unless (-r $bagit."/".$local_name) {
+            _invalid_report_or_die(
+                "cannot read $local_name (bag-path:$bagit)",
+            );
+        }
+    }
     # Evaluate each file against the manifest
     foreach my $alg (keys %{$xxmanifest_entries}) {
         my $manifest_alg = $self->manifests->{$alg};
-        if (! defined $manifest_alg) {
-            next;
-            # TODO: return Errormessage?
-        }
+        next unless (defined $manifest_alg); # FIXME_ errormessage?
         my $digestobj = $manifest_alg->algorithm();
-        my $xxfilename = "${bagit}$xxprefix-$alg.txt";
+        my $xxfilename = "${bagit}/${xxprefix}-${alg}.txt";
+        # first check if each file from payload exists in manifest_entries for given alg
         foreach my $local_name (@payload) {
             # local_name is relative to bagit base
-            my ($digest);
             unless (exists $xxmanifest_entries->{$alg}->{$local_name}) { # localname as value should exist!
-                die("file found which is not in $xxfilename: [$local_name] (bag-path:$bagit)");
+                _invalid_report_or_die(
+                    "file in payload found, which is not in $xxfilename: [$local_name] (bag-path:$bagit)",
+                );
             }
-            if (!-r "$bagit/$local_name") {die("Cannot open $bagit/$local_name");}
-            $digest = $digestobj->verify_file("$bagit/$local_name");
-            print "digest " . $digestobj->name() . " of $bagit/$local_name: $digest\n" if $DEBUG;
+        }
+        # second check if each file from manifest_entries for given alg exists in payload
+        foreach my $local_name ( keys %{ $xxmanifest_entries->{alg} } ) {
+            unless (any { $_ eq $local_name } @payload) {
+                _invalid_report_or_die(
+                    "file expected via $xxfilename,  which is not found in payload: [$local_name] (bag-path:$bagit)"
+                );
+            }
+        }
+        # all preconditions full filled, now calc all digests
+        my sub __calc_digests ($) {
+            my $local_name = shift;
+            # local_name is relative to bagit base
+            my $full_name = $bagit . "/" . $local_name;
+            my $digest = $digestobj->verify_file($full_name);
+            print "digest " . $digestobj->name() . " of $full_name: $digest\n" if $DEBUG;
             my $expected_digest = $xxmanifest_entries->{$alg}->{$local_name};
-            unless ($digest eq $expected_digest) {
-                if ($return_all_errors) {
-                    $invalids{$local_name} = $digest;
-                } else {
-                    die("file: $bagit/$local_name invalid, digest ($alg) calculated=$digest, but expected=$expected_digest in file '$xxfilename'");
+            my $tmp;
+            $tmp->{calculated_digest} = $digest;
+            $tmp->{expected_digest} = $expected_digest;
+            $tmp->{local_name} = $local_name;
+            $tmp;
+        }
+
+        my @digest_hashes;
+        # check if we could use parallel
+        my $is_parallelizeable;
+        if (($self->has_parallel()) && (defined $self->parallel)) {
+            my $err;
+            ($is_parallelizeable, $err) = Class::Load::try_load_class("Parallel::Iterator");
+            if (!$is_parallelizeable) {
+                warn "Class 'Parallel::Iterator' could not be loaded…, $err\n";
+                $self->{parallel} = undef;
+            }
+        }
+        if ($is_parallelizeable) {
+            my $class = Class::Load::load_class("Parallel::Iterator");
+            $class->import( qw(iterate_as_array));
+            @digest_hashes = iterate_as_array (
+                sub {
+                    my ($idx, $local_name) = @_;
+                    return __calc_digests($local_name);
+                }, \@payload);
+        } else { # fallback to serial processing
+            @digest_hashes = map { __calc_digests( $_ ) } @payload;
+        }
+        # compare digests
+        foreach my $digest_entry (@digest_hashes) {
+            unless ($digest_entry->{calculated_digest} eq $digest_entry->{expected_digest}) {
+                _invalid_report_or_die(
+                    sprintf ("file: %s invalid, digest (%s) calculated=%s, but expected=%s in file '%s'",
+                        $digest_entry->{local_name},
+                        $alg,
+                        $digest_entry->{calculated_digest},
+                        $digest_entry->{expected_digest},
+                        $xxfilename
+                    )
+                );
                 }
             }
-            $seen{$alg}{$local_name}=1;
         }
-    }
-    if($return_all_errors && keys(%invalids) ) {
-        foreach my $invalid (keys(%invalids)) {
-            print "invalid: $invalid hash: ".$invalids{$invalid}."\n";
+    if($return_all_errors && @invalid_messages ) {
+        foreach my $invalid (@invalid_messages) {
+            print "$invalid\n";
         }
         die ("bag verify for bagit $version failed with invalid files");
     }
-    # Make sure there are no missing files
-    my @missed;
-    foreach my $alg (keys %seen){
-        foreach my $localfile ( keys %{ $xxmanifest_entries->{$alg} } ) {
-            if (exists $seen{$alg}{$localfile} ) { next;}
-            else {
-                push @missed, "Missing file '$localfile' in bag '$bagit' for algorithm=$alg";
-            }
-        }
-    }
-    if (@missed){
-        die join("\n", @missed);
-    }
     return 1;
 }
 
@@ -605,7 +661,7 @@ sub verify_bag {
 
 
     die("$manifest_file is not a regular file for bagit $version") unless -f ($manifest_file);
-    die("$payload_dir is not a directory") unless -d ($payload_dir);
+    die("$payload_dir is not a directory or does not exist") unless -d ($payload_dir);
 
     unless ($version > .95) {
         die ("Bag Version $version is unsupported");
@@ -756,7 +812,26 @@ Archive::BagIt::Base
 
 =head1 VERSION
 
-version 0.057
+version 0.058
+
+=head1 SYNOPSIS
+
+This modules will hopefully help with the basic commands needed to create
+and verify a bag. This part supports BagIt 1.0 according to RFC 8493 ([https://tools.ietf.org/html/rfc8493](https://tools.ietf.org/html/rfc8493)).
+
+    use Archive::BagIt::Base;
+
+    #read in an existing bag:
+    my $bag_dir = "/path/to/bag";
+    my $bag = Archive::BagIt::Base->new($bag_dir);
+
+
+    #construct bag in an existing directory
+    my $bag2 = Archive::BagIt::Base->make_bag($bag_dir);
+
+    # Validate a BagIt archive against its manifest
+    my $bag3 = Archive::BagIt::Base->new($bag_dir);
+    my $is_valid = $bag3->verify_bag();
 
 =head1 NAME
 
@@ -764,7 +839,7 @@ Archive::BagIt::Base
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 NAME
 
@@ -819,9 +894,37 @@ The actual development version is available at L<https://art1pirat.spdns.org/art
 
 =back
 
-=head2 BUILDARGS
+=head2 Constructor
 
-The constructor sub, will create a bag with a single argument
+The constructor sub, will create a bag with a single argument,
+
+    use Archive::BagIt::Base;
+
+    #read in an existing bag:
+    my $bag_dir = "/path/to/bag";
+    my $bag = Archive::BagIt::Base->new($bag_dir);
+
+or use hashreferences
+
+    use Archive::BagIt::Base;
+
+    #read in an existing bag:
+    my $bag_dir = "/path/to/bag";
+    my $bag = Archive::BagIt::Base->new(
+        bag_path => $bag_dir,
+        parallel => 1
+    );
+
+The arguments are:
+
+=over 1
+
+=item C<bag_path> - path to bag-directory
+
+=item C<parallel> - if set and Parallel::Iterator available, it verifies files in parallel.
+      Hint: use it only for very large bagits, because overhead for parallelization
+
+=back
 
 =head2 load_plugins
 
