@@ -3,10 +3,10 @@ use warnings;
 
 package Archive::BagIt::DotBagIt;
 
-our $VERSION = '0.057'; # VERSION
+our $VERSION = '0.058'; # VERSION
 
 use Sub::Quote;
-use Moose;
+use Moo;
 
 extends "Archive::BagIt::Base";
 
@@ -48,7 +48,7 @@ Archive::BagIt::DotBagIt
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 NAME
 
@@ -56,7 +56,7 @@ Archive::BagIt::DotBagIt
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 NAME
 
