@@ -5,19 +5,19 @@ use warnings;
 
 package Archive::BagIt::Plugin::Algorithm::MD5;
 
-use Moose;
+use Moo;
 use namespace::autoclean;
 
 with 'Archive::BagIt::Role::Algorithm';
 
-has 'plugin_name' => (
+has '+plugin_name' => (
     is => 'ro',
     default => 'Archive::BagIt::Plugin::Algorithm::MD5',
 );
 
-has 'name' => (
+has '+name' => (
     is      => 'ro',
-    isa     => 'Str',
+    #isa     => 'Str',
     default => 'md5',
 );
 
@@ -70,7 +70,7 @@ Archive::BagIt::Plugin::Algorithm::MD5 - The default MD5 algorithm plugin
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 NAME
 
@@ -78,7 +78,7 @@ Archive::BagIt::Plugin::Algorithm::MD5 - The default MD5 algorithm plugin
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 AVAILABILITY
 
