@@ -5,19 +5,19 @@ use warnings;
 
 package Archive::BagIt::Plugin::Algorithm::SHA512;
 
-use Moose;
+use Moo;
 use namespace::autoclean;
 
 with 'Archive::BagIt::Role::Algorithm';
 
-has 'plugin_name' => (
+has '+plugin_name' => (
     is => 'ro',
     default => 'Archive::BagIt::Plugin::Algorithm::SHA512',
 );
 
-has 'name' => (
+has '+name' => (
     is      => 'ro',
-    isa     => 'Str',
+    #isa     => 'Str',
     default => 'sha512',
 );
 
@@ -69,7 +69,7 @@ Archive::BagIt::Plugin::Algorithm::SHA512 - The default SHA algorithms plugin
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 NAME
 
@@ -77,7 +77,7 @@ Archive::BagIt::Plugin::Algorithm::SHA512 - The default SHA algorithms plugin
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 AVAILABILITY
 
