@@ -6,7 +6,7 @@ use warnings;
 
 package Archive::BagIt::Role::Algorithm;
 
-use Moose::Role;
+use Moo::Role;
 with 'Archive::BagIt::Role::Plugin';
 
 has 'name' => (
@@ -32,7 +32,7 @@ sub register_plugin {
     $self->bagit->algos( {$self->name => $self });
     return 1;
 }
-no Moose;
+no Moo;
 1;
 
 __END__
@@ -47,7 +47,7 @@ Archive::BagIt::Role::Algorithm - A role that defines the interface to a hashing
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 NAME
 
@@ -55,7 +55,7 @@ Archive::BagIt::Role::Algorithm - A role that defines the interface to a hashing
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 AVAILABILITY
 
