@@ -2,19 +2,19 @@ use strict;
 use warnings;
 package Archive::BagIt::Role::Plugin;
 
-use Moose::Role;
+use Moo::Role;
 
 use namespace::autoclean;
 
 has plugin_name => (
   is  => 'ro',
-  isa => 'Str',
+  #isa => 'Str',
   default => __PACKAGE__,
 );
 
 has bagit => (
   is  => 'ro',
-  isa => 'Archive::BagIt::Base',
+  #isa => 'Archive::BagIt::Base',
   required => 1,
   weak_ref => 1,
 );
@@ -25,7 +25,7 @@ sub BUILD {
     $self->bagit->plugins( { $plugin_name => $self });
     return 1;
 }
-no Moose;
+no Moo;
 1;
 
 __END__
@@ -40,7 +40,7 @@ Archive::BagIt::Role::Plugin
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 NAME
 
@@ -48,7 +48,7 @@ Archive::BagIt::Role::Plugin
 
 =head1 VERSION
 
-version 0.057
+version 0.058
 
 =head1 AVAILABILITY
 
